==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/compton-conf/compton-conf_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Fenstereffekte einrichten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Schatten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="30"/>
        <source>The blur radius for shadows</source>
        <translation>Unschärferadius</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="40"/>
        <source>The left offset for shadows</source>
        <translation>Versatz von links</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="54"/>
        <source>The top offset for shadows</source>
        <translation>Versatz von oben</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="68"/>
        <source>The translucency for shadows</source>
        <translation>Lichtdurchlässigkeit</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="75"/>
        <source>Color of shadow</source>
        <translation>Schattenfarbe</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="89"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Korrekturen zu Besonderheiten von ARGB Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="92"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Schattenmaske hinter Fenstern abschalten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="99"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Keine Schatten beim Verschieben von Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="106"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Keine Schatten an Dock/Panel-Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="113"/>
        <source>Enabled client-side shadows on windows</source>
        <translation>Aktiviere das Client-seitige Zeichnen von Fensterschatten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="120"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Keine Schatten an allen geformten Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="138"/>
        <source>Opacity</source>
        <translation>Deckkraft</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="147"/>
        <source>The opacity for menus</source>
        <translation>Deckkraft von Menüs</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="154"/>
        <source>Default opacity of inactive windows</source>
        <translation>Default-Deckkraft von inaktiven Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="161"/>
        <source>Default opacity for active windows</source>
        <translation>Default-Deckkraft von aktiven Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="168"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Deckkraft von Fenstertiteln und Rändern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="175"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender Backend: Schrittweite für Bilder mit Transparenz
(höhere Werte können zu niedrigerer X-Nutzung führen)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="183"/>
        <source>Dim inactive windows</source>
        <translation>Abdunkeln von inaktiven Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="190"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Abdunklung ist von der Deckkraft der Fenster unabhängig</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="197"/>
        <source>Blur background of transparent windows</source>
        <translation>Hintergrund von transparenten Fenstern verwischen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="204"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Auch Hintergrund von opaken Fenstern mit transparenten Rahmen verwischen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="211"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Verwischungsradius ist von Deckkraft der Fenster unabhängig</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="279"/>
        <source>Fade</source>
        <translation>Überblenden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="285"/>
        <source>Fade windows during opacity changes</source>
        <translation>Überblendeffekt bei Deckkraft-Änderungen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Zeit zwischen den Überblendschritten in ms</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="299"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Deckkraftänderung je Überblendschritt beim Einblenden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="306"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Deckkraftänderung je Überblendschritt beim Ausblenden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="313"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Überblendeffekt beim Öffnen/Schließen von Fenstern vermeiden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="356"/>
        <source>Other</source>
        <translation>Sonstiges</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="362"/>
        <source>Not implemented yet</source>
        <translation>Noch keine weiteren Einstellungen implementiert</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="375"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="179"/>
        <source>About ComptonConf</source>
        <translation>Über ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="180"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - Konfigurationswerkzeug für compton

Copyright (C) 2013
Autor: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/compton-conf/compton-conf_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Fenstereffekte einrichten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Schatten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Unschärferadius</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Versatz von links</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Versatz von oben</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Lichtdurchlässigkeit</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Schattenfarbe</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Korrekturen zu Besonderheiten von ARGB Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Schattenmaske hinter Fenstern abschalten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Keine Schatten beim Verschieben von Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Keine Schatten an Dock/Panel-Fenstern</translation>
    </message>
    <message>
        <source>Enabled client-side shadows on windows</source>
        <translation type="vanished">Aktiviere das Client-seitige Zeichnen von Fensterschatten</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Keine Schatten an allen geformten Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Deckkraft</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Deckkraft von Menüs</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Default-Deckkraft von inaktiven Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Default-Deckkraft von aktiven Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Deckkraft von Fenstertiteln und Rändern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>XRender Backend: Schrittweite für Bilder mit Transparenz
(höhere Werte können zu niedrigerer X-Nutzung führen)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Abdunkeln von inaktiven Fenstern</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Abdunklung ist von der Deckkraft der Fenster unabhängig</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Hintergrund von transparenten Fenstern verwischen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Auch Hintergrund von opaken Fenstern mit transparenten Rahmen verwischen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Verwischungsradius ist von Deckkraft der Fenster unabhängig</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Überblenden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Überblendeffekt bei Deckkraft-Änderungen</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Zeit zwischen den Überblendschritten in ms</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Deckkraftänderung je Überblendschritt beim Einblenden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Deckkraftänderung je Überblendschritt beim Ausblenden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Überblendeffekt beim Öffnen/Schließen von Fenstern vermeiden</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Sonstiges</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not implemented yet</source>
        <translation type="vanished">Noch keine weiteren Einstellungen implementiert</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>Über ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - Konfigurationswerkzeug für compton

Copyright (C) 2013
Autor: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
